Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS IoT Events.

Actions, resources, and condition keys for AWS IoT Events - Service Authorization Reference

# Actions, resources, and condition keys for AWS IoT Events

AWS IoT Events (service prefix: `iotevents` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS IoT Events
- Resource types defined by AWS IoT Events
- Condition keys for AWS IoT Events

## Actions defined by AWS IoT Events

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchAcknowledgeAlarm | Grants permission to send one or more acknowledge action requests to AWS IoT Events | Write | input* |  |
BatchDisableAlarm | Grants permission to disable one or more alarm instances | Write | input* |  |
BatchEnableAlarm | Grants permission to enable one or more alarm instances | Write | input* |  |
BatchPutMessage | Grants permission to send a set of messages to the AWS IoT Events system | Write | input* |  |
BatchResetAlarm | Grants permission to reset one or more alarm instances | Write | input* |  |
BatchSnoozeAlarm | Grants permission to change one or more alarm instances to the snooze mode | Write | input* |  |
BatchUpdateDetector | Grants permission to update a detector instance within the AWS IoT Events system | Write | input* |  |
CreateAlarmModel | Grants permission to create an alarm model to monitor an AWS IoT Events input attribute or an AWS IoT SiteWise asset property | Write | alarmModel* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDetectorModel | Grants permission to create a detector model to monitor an AWS IoT Events input attribute | Write | detectorModel* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateInput | Grants permission to create an Input in IotEvents | Write | input* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteAlarmModel | Grants permission to delete an alarm model | Write | alarmModel* |  |
DeleteDetectorModel | Grants permission to delete a detector model | Write | detectorModel* |  |
DeleteInput | Grants permission to delete an input | Write | input* |  |
DescribeAlarm | Grants permission to retrieve information about an alarm instance | Read | alarmModel* |  |
DescribeAlarmModel | Grants permission to retrieve information about an alarm model | Read | alarmModel* |  |
DescribeDetector | Grants permission to retriev information about a detector instance | Read | detectorModel* |  |
DescribeDetectorModel | Grants permission to retrieve information about a detector model | Read | detectorModel* |  |
DescribeInput | Grants permission to retrieve an information about Input | Read | input* |  |
DescribeLoggingOptions | Grants permission to retrieve the current settings of the AWS IoT Events logging options | Read |  |  |
ListAlarmModelVersions | Grants permission to list all the versions of an alarm model | List | alarmModel* |  |
ListAlarmModels | Grants permission to list the alarm models that you created | List |  |  |
ListAlarms | Grants permission to retrieve information about all alarm instances per alarmModel | List | alarmModel* |  |
ListDetectorModelVersions | Grants permission to list all the versions of a detector model | List | detectorModel* |  |
ListDetectorModels | Grants permission to list the detector models that you created | List |  |  |
ListDetectors | Grants permission to retrieve information about all detector instances per detectormodel | List | detectorModel* |  |
ListInputs | Grants permission to lists the inputs you have created | List |  |  |
ListTagsForResource | Grants permission to list the tags (metadata) which you have assigned to the resource | Read | detectorModel |  |
input |  |
PutLoggingOptions | Grants permission to set or update the AWS IoT Events logging options | Write |  |  |
TagResource | Grants permission to adds to or modifies the tags of the given resource.Tags are metadata which can be used to manage a resource | Tagging | detectorModel |  |
input |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove the given tags (metadata) from the resource | Tagging | detectorModel |  |
input |  |
| aws:TagKeys |
UpdateAlarmModel | Grants permission to update an alarm model | Write | alarmModel* |  |
UpdateDetectorModel | Grants permission to update a detector model | Write | detectorModel* |  |
UpdateInput | Grants permission to update an input | Write | input* |  |
UpdateInputRouting | Grants permission to update input routing | Write | input* |  |

## Resource types defined by AWS IoT Events

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
detectorModel | `arn:$ { Partition}:iotevents:$ { Region}:$ { Account}:detectorModel/$ { DetectorModelName}` | aws:ResourceTag/${TagKey}
alarmModel | `arn:$ { Partition}:iotevents:$ { Region}:$ { Account}:alarmModel/$ { AlarmModelName}` | aws:ResourceTag/${TagKey}
input | `arn:$ { Partition}:iotevents:$ { Region}:$ { Account}:input/$ { inputName}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS IoT Events

AWS IoT Events defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags attached to the resource | String
aws:TagKeys | Filters actions by the tag keys in the request | String
iotevents:keyValue | Filters access by the instanceId (key-value) of the message | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.